@@ -84,6 +84,8 @@ public slots:
   void slotStop();
   //! \brief ߡ
   void slotPause();
+  //! \brief ߲
+  void slotResume();
   //! \brief ޥݥѹ롣
   //! \param time ְ֡
   void slotSetMasterPosition(const QTime& time);
