@@ -52,7 +52,7 @@ WGanttItem::WGanttItem(
   setMouseTracking(true);
   setCursor(Qt::SizeHorCursor);
 
-  FrameFace = new QFrame(this);
+  FrameFace = new QLabel("", this);
   FrameFace->move(FrameFace->x() + 5, FrameFace->y());
   FrameFace->resize(width() - 10, FrameFace->height());
   FrameFace->setPaletteBackgroundColor(colorFace);
@@ -107,8 +107,13 @@ WGanttItem::slotSetStartPosition(int nStartPosition)
     return;
   } else if ( nStartPosition > length() ) {
     return;
+  } else if ( nStartPosition == startPosition() ) {
+    return;
   }
+
   slotSetLength(nMaxLen - (nStartPosition + nRightDiff), true);
+
+  //!! need to emit??
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -116,7 +121,13 @@ WGanttItem::slotSetStartPosition(int nStartPosition)
 void 
 WGanttItem::slotSetOffset(int nOffset)
 {
+  if ( nOffset == offset() ) {
+    return;
+  }
+
   move(nOffset, y());
+
+  //!! need to emit??
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -126,7 +137,10 @@ WGanttItem::slotSetLength(int nLen, bool bLeft/* =false */)
 {
   if ( nLen > nMaxLen ) {
     return;
+  } else if ( nLen == length() ) {
+    return;
   }
+
   resize(nLen + 10, height());
   FrameFace->resize(nLen, height());
   if ( bLeft ) {
@@ -134,6 +148,8 @@ WGanttItem::slotSetLength(int nLen, bool bLeft/* =false */)
   } else {
     nRightDiff = nMaxLen - nLen;
   }
+
+  //!! need to emit??
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -143,9 +159,22 @@ WGanttItem::slotSetMaximumLength(int nLen)
 {
   if ( nLen < 0 ) {
     return;
+  } else if ( nLen == maximumLength() ) {
+    return;
   }
+
   nMaxLen = nLen;
   reset();
+
+  //!! need to emit??
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+WGanttItem::slotSetText(const QString& strCaption)
+{
+  FrameFace->setText(strCaption);
 }
 
 /////////////////////////////////////////////////////////////////////////////
