@@ -36,7 +36,7 @@ WSoundLocator::WSoundLocator(
   const QTime& timeMaxSession, 
   QWidget*     WidgetParent, 
   const char*  cName)
- : QScrollView(WidgetParent, cName)
+ : QScrollView(WidgetParent, cName), nRemainder(0)
 {
   setFrameStyle(QFrame::WinPanel | QFrame::Plain);
   setHScrollBarMode(QScrollView::AlwaysOn);
@@ -90,8 +90,10 @@ WSoundLocator::bind(const QString& strFileName)
 
   CEcaTools ecaTools;
   QTime time = ecaTools.sourceLength(strFileName);
+  nRemainder = time.msec();
   QTime timeTmp;
   GanttItem->slotSetMaximumLength(timeTmp.secsTo(time));
+  GanttItem->slotSetText(time.toString("mm:ss.zzz"));
   GanttItem->show();
 }
 
@@ -146,7 +148,7 @@ QTime
 WSoundLocator::startPosition() const
 {
   QTime time;
-  return time.addSecs(GanttItem->startPosition());
+  return (time.addSecs(GanttItem->startPosition())).addMSecs(nRemainder);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -155,7 +157,7 @@ QTime
 WSoundLocator::offset() const
 {
   QTime time;
-  return time.addSecs(GanttItem->offset());
+  return (time.addSecs(GanttItem->offset())).addMSecs(nRemainder);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -164,7 +166,7 @@ QTime
 WSoundLocator::length() const
 {
   QTime time;
-  return time.addSecs(GanttItem->length());
+  return (time.addSecs(GanttItem->length())).addMSecs(nRemainder);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -172,6 +174,11 @@ WSoundLocator::length() const
 void 
 WSoundLocator::slotSetStartPosition(const QTime& time)
 {
+  if ( startPosition() == time ) {
+    return;
+  }
+
+  nRemainder = time.msec();
   QTime timeTmp;
   GanttItem->slotSetStartPosition(timeTmp.secsTo(time));
 }
@@ -181,6 +188,11 @@ WSoundLocator::slotSetStartPosition(const QTime& time)
 void 
 WSoundLocator::slotSetOffset(const QTime& time)
 {
+  if ( offset() == time ) {
+    return;
+  }
+
+  nRemainder = time.msec();
   QTime timeTmp;
   GanttItem->slotSetOffset(timeTmp.secsTo(time));
 }
@@ -191,16 +203,40 @@ void
 WSoundLocator::slotSetLength(const QTime& time)
 {
   QTime timeTmp;
+
+  // time is ZERO : souce-length
+  if ( timeTmp.msecsTo(time) == 0 ) {
+    timeTmp = sourceLength();
+    nRemainder = timeTmp.msec();
+    GanttItem->slotSetLength(time.secsTo(timeTmp));
+    GanttItem->slotSetText(timeTmp.toString("mm:ss.zzz"));
+    return;
+  }
+
+  GanttItem->slotSetText(time.toString("mm:ss.zzz"));
+  if ( length() == time ) {
+    return;
+  }
+
+  nRemainder = time.msec();
   GanttItem->slotSetLength(timeTmp.secsTo(time));
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WSoundLocator::slotSetItemEnabled(bool bEnabled)
+{
+  GanttItem->setEnabled(bEnabled);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WSoundLocator::slotChangedStartPosition(int nSecond)
 {
   QTime time;
-  emit startPositionChanged(time.addSecs(nSecond));
+  emit startPositionChanged((time.addSecs(nSecond)).addMSecs(nRemainder));
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -209,7 +245,7 @@ void
 WSoundLocator::slotChangedOffset(int nSecond)
 {
   QTime time;
-  emit offsetChanged(time.addSecs(nSecond));
+  emit offsetChanged((time.addSecs(nSecond)).addMSecs(nRemainder));
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -218,7 +254,7 @@ void
 WSoundLocator::slotChangedLength(int nSecond)
 {
   QTime time;
-  emit lengthChanged(time.addSecs(nSecond));
+  emit lengthChanged((time.addSecs(nSecond)).addMSecs(nRemainder));
 }
 
 /////////////////////////////////////////////////////////////////////////////
