@@ -82,6 +82,8 @@ private:
   WGanttItem *GanttItem;
   //! ե̾Ρ
   QString     strSrcFileName;
+  //! ȥ㡼Ǥʤmillisecond;ꡣ
+  int         nRemainder;
 
 public slots:
   //! \brief κϰ֤ꤹ롣
@@ -90,6 +92,8 @@ public slots:
   void slotSetOffset(const QTime& time);
   //! \brief κĹꤹ롣
   void slotSetLength(const QTime& time);
+  //! \brief ȥ㡼Ǥͭꤹ
+  void slotSetItemEnabled(bool bEnabled);
 
 private slots:
   //! \brief κϰ֤ѹ줿Υåȡ
