@@ -547,11 +547,10 @@ WVoxBase::resizeEvent(QResizeEvent* Event)
 void 
 WVoxBase::timerEvent(QTimerEvent* Event)
 {
-  if ( Event->timerId() == nTimerIDProceed ) {
+  if ( Event->timerId() == nTimerIDProceed ) {  // playing
     timeProceed = timeProceed.addSecs(1);
     TimeEditProceed->setTime(timeProceed);
-  } else if ( Event->timerId() == nTimerIDPausing ) {
-    timeProceed = timeProceed.addSecs(1);
+  } else if ( Event->timerId() == nTimerIDPausing ) {  // pausing
   }
 
   QVBox::timerEvent(Event);
@@ -584,6 +583,7 @@ WVoxBase::slotChangeState(State state)
 {
   QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
 
+  // PLAY
   if ( state == Play ) {
     while ( it != vVoxTracks.end() ) {
       (*it)->slotSetEnabledWidgets(
@@ -601,13 +601,16 @@ WVoxBase::slotChangeState(State state)
       nTimerIDProceed = nTimerIDPausing;
       nTimerIDPausing = 0;
     } else {
-      timeProceed = TimeEditPosition->time();
+      timeProceed = QTime();
+      TimeEditProceed->setTime(timeProceed);
       TimeEditProceed->show();
       LabelProceed->show();
       nTimerIDProceed = startTimer(1000); // 1 second timer
       nTimerIDPausing = 0;
     }
-  } else if ( state == Pause ) {
+  }
+  // PAUSE
+  else if ( state == Pause ) {
     while ( it != vVoxTracks.end() ) {
       (*it)->slotSetEnabledWidgets(
                WVoxTrack::Record |
@@ -625,7 +628,9 @@ WVoxBase::slotChangeState(State state)
     }
     nTimerIDPausing = nTimerIDProceed;
     nTimerIDProceed = 0;
-  } else if ( state == Stop ) {
+  }
+  // STOP
+  else if ( state == Stop ) {
     TimeEditProceed->hide();
     LabelProceed->hide();
     killTimer(nTimerIDProceed);
