@@ -125,12 +125,20 @@ public:
   //! \return DOMΡɡ
   QDomNode stateInDOM(QDomDocument* pDoc);
 
+  //! \brief  åκĹꤹ롣
+  void setMaxSessionLength(const QTime& time);
+
 protected:
   void resizeEvent(QResizeEvent* Event);
+  void timerEvent(QTimerEvent* Event);
 
 private:
   //! ϰ֤ɽ뤿Υåȡ
   QTimeEdit     *TimeEditPosition;
+  //! ʹԻɽѥåȡ
+  QLabel        *LabelProceed;
+  //! ʹԻɽѥåȡ
+  QTimeEdit     *TimeEditProceed;
   //! ȥåǼ٥
   QValueVector<WVoxTrack*> vVoxTracks;
   //! ȥåɽΰ衣
@@ -164,6 +172,16 @@ private:
   //! ȥåĹѹΤΥʥޥåѡ
   QSignalMapper *SignalMapperLength;
 
+  //! åĹ
+  QTime         timeMaxSessionLength;
+
+  //! ʹԻɽѥID
+  int           nTimerIDProceed;
+  //! ߻ХååѥID
+  int           nTimerIDPausing;
+  //! ʹԻ֡
+  QTime         timeProceed;
+
   //! åȤꡣ
   //! 󥹥ȥ饯Τ߸ƤӽФġ
   void setupWidgets();
@@ -182,7 +200,7 @@ public slots:
   //! \brief  ߤȼäơΥåȤ̵ͭꤹ롣
   //! \param  state ξWVoxBase::Playꡢ
   //! ߤξWVoxBase::StopꡢߤξKWVoxBase::Pauseꡣ
-  void slotSetEnabledWidgets(State state);
+  void slotChangeState(State state);
   //! \brief  Ͽλ˸ƤӽФ٤åȡ
   //! ȥåΤϿꤵƤΤΥեåȡ֡Ĺ򥼥ˤ롣
   void slotNotifySucceedInRecording();
