@@ -49,7 +49,7 @@
 /////////////////////////////////////////////////////////////////////////////
 
 WVoxStorm::WVoxStorm(QWidget *WidgetParent, const char *cName)
-  : KMainWindow(WidgetParent, cName)
+  : KMainWindow(WidgetParent, cName), bPause(false)
 {
   initialize();
 
@@ -64,7 +64,7 @@ WVoxStorm::WVoxStorm(
   const QString& strFileName, 
   QWidget* WidgetParent, 
   const char* cName)
-  : KMainWindow(WidgetParent, cName)
+  : KMainWindow(WidgetParent, cName), bPause(false)
 {
   initialize();
 
@@ -98,6 +98,8 @@ WVoxStorm::initialize()
   readConfigurationFile();
 
   VoxBase = new WVoxBase(this, "VoxBase");
+  setCentralWidget(VoxBase);
+
   connect(VoxBase, SIGNAL(playbackDeviceChanged(const QString&, const QString&)),
           this, SLOT(slotChangePlaybackDevice(const QString&, const QString&)));
   connect(VoxBase, SIGNAL(recordingDeviceChanged(const QString&, const QString&)),
@@ -121,8 +123,6 @@ WVoxStorm::initialize()
   connect(VoxBase, SIGNAL(lengthChanged(const QString&, const QTime&)),
           this, SLOT(slotChangeLength(const QString&, const QTime&)));
 
-  setCentralWidget(VoxBase);
-
   connect(VoxBase, SIGNAL(masterPositionChanged(const QTime&)),
           &EcaIAManager, SLOT(slotSetMasterPosition(const QTime&)));
   connect(&EcaIAManager, SIGNAL(masterPositionChanged(const QTime&)),
@@ -439,7 +439,7 @@ WVoxStorm::setupActions()
   menuBar()->insertItem(i18n("&Settings"), PopupMenu);
 
   QString strHelp =
-            i18n("VoxStorm 0.1\n\n"
+            i18n("VoxStorm 0.2\n\n"
                  "(C) 2003-2004 Tomoaki Murakami\n"
                  "solarisphere@yahoo.co.jp\n"
                  "Simple MTR using Ecasound on KDE\n");
@@ -779,19 +779,29 @@ WVoxStorm::slotPlay()
     LabelStatusBar->setText(i18n("Playing..."));
   }
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotRemoveAllChains();
-    int nCount = VoxBase->getTrackCount();
-    int i;
-    for ( i = 0; i < nCount; i++ ) {
-      EcaIAManager.slotAddChain(VoxBase->getTrackInf(i));
-    }
+    if ( bPause ) {  // PAUSE -> PLAY
+      ActionPlay->setEnabled(false);
+      ToggleActionRec->setEnabled(false);
+      ActionMixdown->setEnabled(false);
+      VoxBase->slotChangeState(WVoxBase::Play);
+      VoxBase->slotChangeMessageTab(WVoxBase::Console);
+      EcaIAManager.slotResume();
+      bPause = false;
+    } else {         // STOP  -> PLAY
+      EcaIAManager.slotRemoveAllChains();
+      int nCount = VoxBase->getTrackCount();
+      int i;
+      for ( i = 0; i < nCount; i++ ) {
+        EcaIAManager.slotAddChain(VoxBase->getTrackInf(i));
+      }
 
-    ActionPlay->setEnabled(false);
-    ToggleActionRec->setEnabled(false);
-    ActionMixdown->setEnabled(false);
-    VoxBase->slotChangeState(WVoxBase::Play);
-    VoxBase->slotChangeMessageTab(WVoxBase::Console);
-    EcaIAManager.slotPlay(ToggleActionRec->isChecked());
+      ActionPlay->setEnabled(false);
+      ToggleActionRec->setEnabled(false);
+      ActionMixdown->setEnabled(false);
+      VoxBase->slotChangeState(WVoxBase::Play);
+      VoxBase->slotChangeMessageTab(WVoxBase::Console);
+      EcaIAManager.slotPlay(ToggleActionRec->isChecked());
+    }
   } else {
   }
   QApplication::restoreOverrideCursor();
@@ -813,7 +823,10 @@ WVoxStorm::slotPause()
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotPause();
+    ActionPlay->setEnabled(true);
     VoxBase->slotChangeState(WVoxBase::Pause);
+    LabelStatusBar->setText(i18n("Pausing..."));
+    bPause = true;
   }
   QApplication::restoreOverrideCursor();
 }
@@ -1143,6 +1156,7 @@ WVoxStorm::slotFinish()
   ToggleActionRec->setEnabled(true);
   ActionPlay->setEnabled(true);
   LabelStatusBar->setText("");
+  bPause = false;
 }
 
 /////////////////////////////////////////////////////////////////////////////
