@@ -186,6 +186,12 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
           this, SLOT(slotSetLength(const QTime&)));
   connect(Locator, SIGNAL(contentsMoving(int, int)), 
           this, SLOT(slotMovedContents(int)));
+  connect(this, SIGNAL(startPositionChanged(const QTime&)), 
+          Locator, SLOT(slotSetStartPosition(const QTime&)));
+  connect(this, SIGNAL(offsetChanged(const QTime&)), 
+          Locator, SLOT(slotSetOffset(const QTime&)));
+  connect(this, SIGNAL(lengthChanged(const QTime&)), 
+          Locator, SLOT(slotSetLength(const QTime&)));
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -585,7 +591,9 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
         ;
       } else {
         QDomNode nodValue = nnmAttributes.namedItem("value");
-        timeStartPosition.addMSecs(nodValue.nodeValue().toInt());
+        QTime timeTmp;
+        slotSetStartPosition(timeTmp.addMSecs(nodValue.nodeValue().toInt()));
+	//        timeStartPosition.addMSecs(nodValue.nodeValue().toInt());
       }
     }
   }
@@ -602,7 +610,9 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
         ;
       } else {
         QDomNode nodValue = nnmAttributes.namedItem("value");
-        timeOffset.addMSecs(nodValue.nodeValue().toInt());
+        QTime timeTmp;
+        slotSetOffset(timeTmp.addMSecs(nodValue.nodeValue().toInt()));
+	//        timeOffset.addMSecs(nodValue.nodeValue().toInt());
       }
     }
   }
@@ -619,7 +629,9 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
         ;
       } else {
         QDomNode nodValue = nnmAttributes.namedItem("value");
-        timeLength.addMSecs(nodValue.nodeValue().toInt());
+        QTime timeTmp;
+        slotSetLength(timeTmp.addMSecs(nodValue.nodeValue().toInt()));
+	//        timeLength.addMSecs(nodValue.nodeValue().toInt());
       }
     }
   }
@@ -678,15 +690,15 @@ WVoxTrack::slotSetEnabledWidgets(unsigned int unWidgets, bool bEnabled)
   }
   if ( unWidgets & StartPosition ) {
     PopupMenu->setItemEnabled(nMenuIDStartPosition, bEnabled);
-    Locator->setEnabled(bEnabled);
+    Locator->slotSetItemEnabled(bEnabled);
   }
   if ( unWidgets & Offset ) {
     PopupMenu->setItemEnabled(nMenuIDOffset, bEnabled);
-    Locator->setEnabled(bEnabled);
+    Locator->slotSetItemEnabled(bEnabled);
   }
   if ( unWidgets & Length ) {
     PopupMenu->setItemEnabled(nMenuIDLength, bEnabled);
-    Locator->setEnabled(bEnabled);
+    Locator->slotSetItemEnabled(bEnabled);
   }
 }
 
